# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.10] - 2025-04-09

### Fixed

- Fix issue with GitHub release-to-pypi workflow and auto-generated releases conflicting with UI-initiated releases.

## [0.1.9] - 2025-04-09

### Fixed

- Fix issue with GitHub release-to-pypi workflow and auto-generated releases conflicting with UI-initiated releases.

## [0.1.8] - 2025-04-09

### Fixed

- Fix issue with GitHub release-to-pypi workflow and auto-generated releases conflicting with UI-initiated releases.

## [0.1.7] - 2025-04-09

### Fixed

- Fix issue with GitHub release-to-pypi workflow and auto-generated releases conflicting with UI-initiated releases.

###

## [0.1.6] - 2025-04-08

### Added

- Add initial version of CLI utility.
